import { AfterContentInit, DoCheck, QueryList, Signal } from '@angular/core';
import { AbstractControl, ControlContainer } from '@angular/forms';
import { ValdemortConfig } from './valdemort-config.service';
import { DefaultValidationErrors } from './default-validation-errors.service';
import { ValidationErrorDirective } from './validation-error.directive';
import { ValidationFallbackDirective } from './validation-fallback.directive';
import * as i0 from "@angular/core";
interface FallbackError {
    type: string;
    value: any;
}
interface ErrorsToDisplay {
    errors: Array<ValidationErrorDirective>;
    fallback: ValidationFallbackDirective | undefined;
    fallbackErrors: Array<FallbackError>;
}
type ViewModel = {
    shouldDisplayErrors: false;
} | {
    shouldDisplayErrors: true;
    errorsToDisplay: ErrorsToDisplay;
    control: AbstractControl;
};
/**
 * Component allowing to display validation error messages associated to a given form control, form group or form array.
 * The control is provided using the `control` input of the component. If it's used inside an enclosing form group or
 * form array, it can instead be provided using the `controlName` input of the component.
 *
 * Example usage where the control itself is being passed as input:
 * ```
 *   <val-errors [control]="form.controls.birthDate">
 *     <ng-template valError="required">The birth date is mandatory</ng-template>
 *     <ng-template valError="max" let-error="error">The max value for the birth date is {{ error.max | number }}</ng-template>
 *   </val-errors>
 * ```
 *
 * Example usage where the control name is being passed as input:
 * ```
 *   <val-errors controlName="birthDate">
 *     <ng-template valError="required">The birth date is mandatory</ng-template>
 *     <ng-template valError="max" let-error="error">The max value for the birth date is {{ error.max | number }}</ng-template>
 *   </val-errors>
 * ```
 *
 * This component, if the control is invalid, displays its validation errors using the provided templates.
 * The templates, as shown in the above example, have access to the validation error itself.
 *
 * The label of the control can also be provided as input, and then used in the templates:
 * ```
 *   <val-errors controlName="birthDate" label="the birth date">
 *     <ng-template valError="required" let-label>{{ label }} is mandatory</ng-template>
 *     <ng-template valError="max" let-error="error" let-label>The max value for {{ label }} is {{ error.max | number }}</ng-template>
 *   </val-errors>
 * ```
 *
 * The component‘s behavior is configured globally by the Config service (see its documentation for more details). It can
 * - display the first error, or all the errors
 * - add CSS classes to its host `<val-errors>` element
 * - add CSS classes to each error message element being displayed
 * - choose when to display the errors (dirty, touched, touched and submitted, etc.)
 *
 * Global, default templates can be defined (and used by this component) using the default validation errors directive
 * (see its documentation for details). So, if the default error messages are defined and sufficient for a given control, all you
 * need is
 *
 * ```
 * <val-errors controlName="birthDate"></val-errors>
 * ```
 *
 * or, if the default templates expect a label:
 *
 * ```
 * <val-errors controlName="birthDate" label="the birth date"></val-errors>
 * ```
 *
 * If, however, you want to override one or several error messages by custom ones, you can do so by simply defining them inside the
 * component:
 *
 * ```
 * <val-errors controlName="birthDate" label="the birth date">
 *   <ng-template valError="max">You're too young, sorry</ng-template>
 * </val-errors>
 * ```
 *
 * A fallback template can also be provided. This fallback template is used for all the errors that exist on the form control
 * but are not handled by any of the specific error templates:
 * ```
 * <val-errors controlName="birthDate" label="the birth date">
 *   <ng-template valError="max">You're too young, sorry</ng-template>
 *   <ng-template valFallback let-label let-type="type" let-error="error">{{ label }} has an unhandled error of type {{ type }}: {{ error | json }}</ng-template>
 * </val-errors>
 * ```
 * Note that, the fallback template can also be defined in the default validation errors directive (see its documentation for details).
 * If a fallback template is defined inside `val-errors`, it overrides the default fallback.
 *
 * If an error is present on the control, but doesn't have any template, default template or fallback template defined for its type,
 * then it's not displayed. If the control is valid, or if none of the errors of the component has a matching template or default template,
 * then this component itself is hidden.
 */
export declare class ValidationErrorsComponent implements AfterContentInit, DoCheck {
    private config;
    private defaultValidationErrors;
    private controlContainer;
    /**
     * The FormControl, FormGroup or FormArray containing the validation errors.
     * If set, the controlName input is ignored
     */
    control: AbstractControl | null;
    /**
     * The name (or the index, in case it's contained in a FormArray) of the FormControl, FormGroup or FormArray containing the validation
     * errors.
     * Ignored if the control input is set, and only usable if the control to validate is part of a control container
     */
    controlName: string | number | null;
    /**
     * The label of the field, exposed to templates so they can use it in the error message.
     */
    label: string | null;
    /**
     * The list of validation error directives (i.e. <ng-template valError="...">) contained inside the component element.
     */
    errorDirectives: QueryList<ValidationErrorDirective>;
    /**
     * The validation fallback directive (i.e. <ng-template valFallback>) contained inside the component element.
     */
    fallbackDirective: ValidationFallbackDirective | undefined;
    readonly vm: Signal<ViewModel>;
    readonly errorsClasses: string;
    readonly errorClasses: string;
    private validationStateChanges;
    private contentInit;
    /**
     * @param config the Config service instance, defining the behavior of this component
     * @param defaultValidationErrors the service holding the default error templates, optionally
     * defined by using the default validation errors directive
     * @param controlContainer one of the 4 form group or form array directives that can "wrap" the control.
     * It's injected so that we can know if it exists and, if it does, if its form directive has been submitted or not:
     * the config service shouldDisplayErrors function can choose (and does by default) to use that information.
     */
    constructor(config: ValdemortConfig, defaultValidationErrors: DefaultValidationErrors, controlContainer: ControlContainer);
    ngAfterContentInit(): void;
    ngDoCheck(): void;
    private shouldDisplayErrors;
    private findErrorsToDisplay;
    private findActualControl;
    private hasDisplayableError;
    static ɵfac: i0.ɵɵFactoryDeclaration<ValidationErrorsComponent, [null, null, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ValidationErrorsComponent, "val-errors", never, { "control": { "alias": "control"; "required": false; }; "controlName": { "alias": "controlName"; "required": false; }; "label": { "alias": "label"; "required": false; }; }, {}, ["fallbackDirective", "errorDirectives"], never, true, never>;
}
export {};
